pub broadcast proof fn lemma_iset_remove_insert<A>(s: ISet<A>, a: A)Expand description
requires
s.contains(a),ensures(#[trigger] s.remove(a)).insert(a) == s,Removing an element a from a set s and then inserting a back into the set is equivalent to the original sets`.